var game = new Phaser.Game(800, 550, Phaser.CANVAS, 'phaser-example', { preload: preload, create: create, update: update, render: render });

function preload() {

    //  You can fill the preloader with as assets 
    game.load.image('flyer', 'assets/sprites/phaser-dude.png');
	game.load.image('bullet', 'assets/sprites/bullet.png');
	game.load.image('wasp', 'assets/sprites/wasp.png');
}

var player;
var scoreString ;
var bullets;
var bulletTime = 0;
var wasp;
var score=0;
var x;
var y;
var lives=3;


function create() {

    game.physics.startSystem(Phaser.Physics.ARCADE);

    //  This creates a simple sprite that is using our loaded image and displays it on-screen and assign it to a variable
    player = game.add.sprite(400, 300, 'flyer');
	game.physics.enable(player, Phaser.Physics.ARCADE);
	player.anchor.setTo(0.5, 0.5);
	player.body.collideWorldBounds = true;
	
	bullets = game.add.sprite(300, 100, 'bullet');
	bullets.visible=false;
	
	enemybullets = game.add.sprite(300, 100, 'bullet');
	enemybullets.visible=false;

	wasp = game.add.sprite(450, 150, 'wasp');
	game.physics.enable(wasp, Phaser.Physics.ARCADE);
	wasp.anchor.setTo(0.5, 0.5);
	wasp.body.collideWorldBounds = true;
	

	game.physics.enable(bullets, Phaser.Physics.ARCADE);
	game.physics.enable(enemybullets, Phaser.Physics.ARCADE);
	//bullets.body.collideWorldBounds = true;
	
	   //  Our bullet group
    bullets = game.add.group();
    bullets.enableBody = true;
    bullets.physicsBodyType = Phaser.Physics.ARCADE;
    bullets.createMultiple(30, 'bullet');
    bullets.setAll('anchor.x', 0.5);
    bullets.setAll('anchor.y', 1);
    bullets.setAll('outOfBoundsKill', true);
    bullets.setAll('checkWorldBounds', true);

       //  Our enemybullet group
    enemybullets = game.add.group();
    enemybullets.enableBody = true;
    enemybullets.physicsBodyType = Phaser.Physics.ARCADE;
    enemybullets.createMultiple(5, 'bullet');
    enemybullets.setAll('anchor.x', 0.5);
    enemybullets.setAll('anchor.y', 1);
    enemybullets.setAll('outOfBoundsKill', true);
    enemybullets.setAll('checkWorldBounds', true);

	
    //  This gets it moving
    player.body.velocity.setTo(0, 0);
    
    //  This makes the game world bounce-able
    player.body.collideWorldBounds = true;
    
    //  This sets the image bounce energy for the horizontal  and vertical vectors (as an x,y point). "1" is 100% energy return
    //player.body.bounce.set(0.8);

    //player.body.gravity.set(0, 180);
	player.body.gravity.set(0, 0);
	
	//  The score
    scoreString = 'Score : ';
    scoreText = game.add.text(10, 10, scoreString + score, { font: '34px Arial', fill: '#fff' });
	
	//  Lives
    livesString = 'Lives : ';
    livesText=game.add.text(game.world.width - 140, 10, livesString +lives, { font: '34px Arial', fill: '#fff' });
	
	//  Text
    stateText = game.add.text(game.world.centerX,game.world.centerY,' ', { font: '84px Arial', fill: '#fff' });
    stateText.anchor.setTo(0.5, 0.5);
    stateText.visible = false;


}

function update () {
if(!stateText.visible)
{
    // nothing required here
       //  Reset the players velocity (movement)
    //player.body.velocity.x = 0;
	cursors = game.input.keyboard.createCursorKeys();
	fireButton = game.input.keyboard.addKey(Phaser.Keyboard.SPACEBAR);
    
	if (cursors.left.isDown)
    {
        //  Move to the left
        player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.x-=5;
        //player.animations.play('left');
    }
    else if (cursors.right.isDown)
    {
        //  Move to the right
		player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.x+=5;
        //player.animations.play('right');
    }
	else if (cursors.up.isDown)
    {
        //  Move to the down
        player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.y-=5;
        //player.animations.play('right');
    }
	else if (cursors.down.isDown)
    {
        //  Move to the up
        player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.y+=5;
    }
	//  Firing?
        if (fireButton.isDown)
        {
            fireBullet();
        }
    //else
    //{
        //  Stand still
        //player.animations.stop();

        //player.frame = 4;
    //}
		fireEnemyBullet()
	      //  Run collision
		game.physics.arcade.collide(wasp, bullets, collisionHandler, null, this);
		//game.physics.arcade.collide(wasp, player, collisionHandlerDie, null, this);
        //game.physics.arcade.overlap(wasp, player, collisionHandlerDie, null, this);
		game.physics.arcade.overlap(player, enemybullets, collisionHandlerDie, null, this);
}		
}

function fireBullet () {

    //  To avoid them being allowed to fire too fast we set a time limit
    if (game.time.now > bulletTime)
    {
        //  Grab the first bullet we can from the pool
        bullet = bullets.getFirstExists(false);

        if (bullet)
        {
            //  And fire it
            bullet.reset(player.x+10, player.y + 8);
            bullet.body.velocity.y = -400;
            bulletTime = game.time.now + 200;
        }
    }
}
function fireEnemyBullet () {

    //  To avoid them being allowed to fire too fast we set a time limit
    if (game.time.now > bulletTime)
    {
        //  Grab the first bullet we can from the pool
        enemybullet = enemybullets.getFirstExists(false);

        if (enemybullet)
        {
            //  And fire it
            //enemybullet.reset(wasp.x+10, wasp.y + 8);
			enemybullet.reset(wasp.x+game.rnd.integerInRange(-50, 50), wasp.y + 8);
            enemybullet.body.velocity.y = 400;
            enemybulletTime = game.time.now + 200;
        }
    }
}

function resetBullet (enemybullet) {
    //  Called if the bullet goes out of the screen
    enemybullet.kill();
}
function resetBullet (bullet) {
    //  Called if the bullet goes out of the screen
    bullet.kill();
}


function render () {
    //debug helper
    //game.debug.spriteInfo(player, 32, 32);
}

function collisionHandler (wasp, bullet) {
   
    //  When a bullet hits an alien we kill the bullet
    bullet.kill();
    //wasp.kill();

    //  Increase the score
    score += 20;
    scoreText.text = scoreString + score;
	wasp.body.x=game.rnd.integerInRange(10, 600);
	wasp.body.y=game.rnd.integerInRange(10, 300);
	wasp.body.velocity.x=0
	wasp.body.velocity.y=0
}

function collisionHandlerDie (player, enemybullet) {
   
    //  When a bullet hits an alien we kill the bullet
    enemybullet.kill();

    
	if (lives>1)
	{
		//  Decrease lives
		lives -=1;
		livesText.text = livesString + lives;
		player.body.x=game.rnd.integerInRange(10, 600);
		player.body.y=game.rnd.integerInRange(10, 300);
		player.body.velocity.x=0
		player.body.velocity.y=0
		
	}
	else
	{
		lives =0;
		livesText.text = livesString + lives;
		stateText.text=" GAME OVER \n Click to restart";
        stateText.visible = true;
		enemybullets.callAll('kill',this);
		wasp.kill();
		player.kill();

        //the "click to restart" handler
        game.input.onTap.addOnce(restart,this);
	}
}

function restart () {

    //  A new level starts
    
    //resets the life count
    //lives.callAll('revive');
    //  And brings the aliens back from the dead :)
    //aliens.removeAll();
    //createAliens();

    //revives the player
    player.revive();
	//revive the enemy
	wasp.revive();
    //hides the text
    stateText.visible = false;
	lives =3;

}
