var game = new Phaser.Game(800, 550, Phaser.CANVAS, 'phaser-example', { preload: preload, create: create, update: update, render: render });
var player;
var wasp;
var bulletTime = 5;

function preload() {
    //  You can fill the preloader with as assets 
    game.load.image('flyer', 'assets/sprites/phaser-dude.png');
	game.load.image('wasp', 'assets/sprites/wasp.png');
	game.load.image('bullet', 'assets/sprites/bullet.png');
}

function create() {

    game.physics.startSystem(Phaser.Physics.ARCADE);

    //  This creates a simple sprite that is using our 
	// loaded image and displays it on-screen and assign it to a variable
    player = game.add.sprite(400, 300, 'flyer');
	game.physics.enable(player, Phaser.Physics.ARCADE);
	// set an anchor if we would like to rotate the sprite around this xy-points.
	// 0,0 eq upper left corner, and 1,1 eq lower right corner.
	player.anchor.setTo(0.5, 0.5);
	//  This makes the game world bounce-able
	player.body.collideWorldBounds = true;
	// Add bullets to the player
	bullets = game.add.sprite(300, 100, 'bullet');
	bullets.visible=false;
	game.physics.enable(bullets, Phaser.Physics.ARCADE);
	//  Our bullet group
    bullets = game.add.group();
    bullets.enableBody = true;
    bullets.physicsBodyType = Phaser.Physics.ARCADE;
	// Max 30 bullets at the same time on screen
    bullets.createMultiple(30, 'bullet');
    bullets.setAll('anchor.x', 0.5);
    bullets.setAll('anchor.y', 1);
    bullets.setAll('outOfBoundsKill', true);
    bullets.setAll('checkWorldBounds', true);
	
	wasp = game.add.sprite(450, 150, 'wasp');
	game.physics.enable(wasp, Phaser.Physics.ARCADE);
	// set an anchor if we would like to rotate the sprite around this xy-points.
	// 0,0 eq upper left corner, and 1,1 eq lower right corner.
	wasp.anchor.setTo(0.5, 0.5);
	//  This makes the game world bounce-able
	wasp.body.collideWorldBounds = true;
}

function update () {
//rotate the wasp enemy
wasp.rotation += 0.01;
	
	//Read keyboard
	cursors = game.input.keyboard.createCursorKeys();
	fireButton = game.input.keyboard.addKey(Phaser.Keyboard.SPACEBAR);
    
	//Move player according to pressed key
	if (cursors.left.isDown)
    {
        //  Move to the left
        player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.x-=5;
    }
    else if (cursors.right.isDown)
    {
        //  Move to the right
		player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.x+=5;
    }
	else if (cursors.up.isDown)
    {
        //  Move to the down
        player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.y-=5;
    }
	else if (cursors.down.isDown)
    {
        //  Move to the up
        player.body.velocity.x = 0;
		player.body.velocity.y = 0;
        player.y+=5;
    }
	//  Firing?
    if (fireButton.isDown)
    {
		// Fire bullets
        fireBullet();
    }
	// Check if a bullet hits the enemy wasp
	game.physics.arcade.collide(wasp, bullets, collisionHandler, null, this);
}

function render () {

}

function fireBullet () {

    //  To avoid them being allowed to fire too fast we set a time limit
    if (game.time.now > bulletTime)
    {
        //  Grab the first bullet we can from the pool
        bullet = bullets.getFirstExists(false);

        if (bullet)
        {
            //  And fire it
            bullet.reset(player.x+10, player.y + 8);
            bullet.body.velocity.y = -400;
            bulletTime = game.time.now + 200;
        }
    }
}

function resetBullet (bullet) {
    //  Called if the bullet goes out of the screen
    bullet.kill();
}

function collisionHandler (wasp, bullet) {
   
    //  When a bullet hits the enemy wasp we kill the bullet
    bullet.kill();
	
	// Place the enemy wasp at a random position
	wasp.body.x=game.rnd.integerInRange(10, 600);
	wasp.body.y=game.rnd.integerInRange(10, 300);
	wasp.body.velocity.x=0
	wasp.body.velocity.y=0
}


